Module Family - Nautobot Documentation

Skip to content

# Module Families

Added in version 2.4.11

A module family represents a group of related module types. A module family can be optionally assigned to a module bay or module bay template. A module bay assigned to a module family will only accept module types from the same family. This is useful, for example, to ensure that only transceivers are installed in SFP slots. Each module family must have a unique name and may have a description assigned to it.